@@ -48,7 +48,7 @@ impl Routine {
 
                 let l = match self.data.get(pc) {
                     Some(some) => *some,
-                    None => return Err(CallError::from(format!("can not get from index {}", pc + 1)))
+                    None => return Err(CallError::from(format!("can not get from index {}", pc)))
                 };
 
                 c = match (*self.env).alloc(l as usize) {
@@ -60,7 +60,7 @@ impl Routine {
 
                 let l = match self.data.get(pc) {
                     Some(some) => *some,
-                    None => return Err(CallError::from(format!("can not get from index {}", pc + 1)))
+                    None => return Err(CallError::from(format!("can not get from index {}", pc)))
                 };
 
                 c = match (*self.env).dealloc(l as usize) {
@@ -72,7 +72,7 @@ impl Routine {
 
                 let l = match self.data.get(pc) {
                     Some(some) => *some,
-                    None => return Err(CallError::from(format!("can not get from index {}", pc + 1)))
+                    None => return Err(CallError::from(format!("can not get from index {}", pc)))
                 };
 
                 return Ok(Err(l as usize));
@@ -81,7 +81,7 @@ impl Routine {
 
                 let l = match self.data.get(pc) {
                     Some(some) => *some,
-                    None => return Err(CallError::from(format!("can not get from index {}", pc + 1)))
+                    None => return Err(CallError::from(format!("can not get from index {}", pc)))
                 };
 
                 return Ok(Ok(l as usize));
@@ -90,14 +90,14 @@ impl Routine {
 
                 let l = match self.data.get(pc) {
                     Some(some) => *some,
-                    None => return Err(CallError::from(format!("can not get from index {}", pc + 1)))
+                    None => return Err(CallError::from(format!("can not get from index {}", pc)))
                 };
 
                 pc += 1;
 
                 let r = match self.data.get(pc) {
                     Some(some) => *some,
-                    None => return Err(CallError::from(format!("can not get from index {}", pc + 1)))
+                    None => return Err(CallError::from(format!("can not get from index {}", pc)))
                 };
 
                 let mut argv_p: Vec<usize> = Vec::new();
@@ -129,11 +129,23 @@ impl Routine {
                 };
             } else if self.data[pc] == RETURN_C {
                 return Ok(Ok(c as usize));
+            } else if self.data[pc] == FETCH_ARG {
+                pc += 1;
+
+                let l = match self.data.get(pc) {
+                    Some(some) => *some,
+                    None => return Err(CallError::from(format!("can not get from index {}", pc)))
+                };
+
+                c = match argv.get(l as usize) {
+                    Some(some) => *some as i128,
+                    None => return Err(CallError::from(format!("can not get from index {} of argv", l)))
+                };
             } else {
                 pc += 1;
             }
         }
 
-        Ok(Ok(0))
+        Err(CallError::from(format!("routine ended without return")))
     }
 }
